#!/bin/bash

source ${NVM_DIR}/nvm.sh

# //pkgs.dev.azure.com/${AZURE_ARTIFACTS}/_packaging/${AZURE_ARTIFACTS}/npm/registry/
# Test ENVVARS and set a private npm registry if available
if [ -n "$AWS_ARTIFACTS" -a "$AWS_ARTIFACTS" = "enabled" ]; then
    echo "Using AWS Code Artifacts registry to pull packages"
    if [ -n "$AWS_ARTIFACTS_KEY" -a -n "$AWS_ARTIFACTS_SECRET" ]; then
        echo "always-auth=true" >> ~/.npmrc
        AWS_ACCESS_KEY_ID=$AWS_ARTIFACTS_KEY AWS_ACCESS_KEY_SECRET=$AWS_ARTIFACTS_SECRET  aws codeartifact login --tool npm --repository builderdevops --domain builderdevops --domain-owner 058759457265 --region us-east-1 
    else
        echo "Unable to Authenticate to AWS CodeArtifacts as missing credentials, default npm.js will be used"
    fi
elif [ -n "$AZURE_ARTIFACTS" -a -n "$AZURE_ARTIFACTS_TOKEN" ]; then
    echo "Using Azure Artifacts registry '${AZURE_ARTIFACTS}' to pull packages"
    AZURE_ARTIFACTS_FEED=$AZURE_ARTIFACTS
    AZURE_ARTIFACTS_HOST="pkgs.dev.azure.com/${AZURE_ARTIFACTS}/_packaging/${AZURE_ARTIFACTS_FEED}/npm"
    npm config set registry "https://${AZURE_ARTIFACTS_HOST}/registry/"
    yarn config set registry "https://${AZURE_ARTIFACTS_HOST}/registry/"
    echo "always-auth=true" >> ~/.npmrc
    echo "//${AZURE_ARTIFACTS_HOST}/registry/:username=builderdevops" >> ~/.npmrc
    echo "//${AZURE_ARTIFACTS_HOST}/registry/:_password=${AZURE_ARTIFACTS_TOKEN}" >> ~/.npmrc
    echo "//${AZURE_ARTIFACTS_HOST}/registry/:email=devops@builder.ai" >> ~/.npmrc
    echo "//${AZURE_ARTIFACTS_HOST}/:username=builderdevops" >> ~/.npmrc
    echo "//${AZURE_ARTIFACTS_HOST}/:_password=${AZURE_ARTIFACTS_TOKEN}" >> ~/.npmrc
    echo "//${AZURE_ARTIFACTS_HOST}/:email=devops@builder.ai" >> ~/.npmrc
elif [ -n "$NPM_CACHE_REGISTRY_HOST" -a -n "$NPM_AUTH_TOKEN" ]; then
    echo "Using private npm registry to pull packages"
    NPM_REGISTRY_URL="https://${NPM_CACHE_REGISTRY_HOST}/"
    npm config set registry "${NPM_REGISTRY_URL}"
    yarn config set registry "${NPM_REGISTRY_URL}"
    echo "//${NPM_CACHE_REGISTRY_HOST}//:_authToken=${NPM_AUTH_TOKEN}" >> ~/.npmrc
    echo "npm registry set to - $(npm config get registry)"
fi
echo "Node version = $(node --version)"
echo "NPM version = $(npm --version)"
echo "Yarn version = $(yarn --version)"
echo "NPM registry = $(npm config get registry)"
echo "Yarn registry = $(yarn config get registry)"
